@@ -56,7 +56,7 @@ dir.create(alltemp)
 for (pkgname in c("full", "teaching", "minimal")) {
   # No "additional" with create_fusen
   # {fusen} steps
-  path_foosen <- normalize_path_winslash(file.path(alltemp, pkgname))
+  path_foosen <- normalize_path_winslash(file.path(alltemp, pkgname), mustWork = FALSE)
   dev_file <- create_fusen(path_foosen, template = pkgname, open = FALSE)
   flat_file <- dev_file[grepl("flat_", dev_file)]
 
